macro_rules! iorw {
($ty:expr, $nr:expr, $sz:expr) => { ... };
}Expand description
Encode an ioctl command that both reads and writes.
macro_rules! iorw {
($ty:expr, $nr:expr, $sz:expr) => { ... };
}Encode an ioctl command that both reads and writes.